import React, { useMemo } from 'react';
import { Link, Route } from 'react-router-dom';
import { store } from '@component-controls/store/controls-store';
import { getIndexPage, getHomePages, getDocPages } from '@component-controls/routes';
import { AppContext, DocPage, DocumentHomePage } from '@component-controls/app';
import { Helmet } from 'react-helmet';
import { __rest } from 'tslib';
import { defDocType } from '@component-controls/core';

const ReactRouterLink = (_a) => {
    var { href = '', children } = _a, props = __rest(_a, ["href", "children"]);
    return (React.createElement(Link, Object.assign({ to: href }, props), children));
};

const Layout = ({ docId, storyId, children, activeTab, }) => {
    return (React.createElement(AppContext, { Helmet: Helmet, docId: docId, storyId: storyId, store: store, linkClass: ReactRouterLink, activeTab: activeTab }, children));
};

const DocPageTemplate = ({ docId, storyId, type, activeTab, category, }) => {
    const DocHome = () => (React.createElement(Layout, { docId: docId, storyId: storyId, activeTab: activeTab },
        React.createElement(DocPage, { type: type, category: category })));
    return DocHome;
};

const DocHomeTemplate = ({ type = defDocType, docId, storyId, }) => {
    const DocHome = () => (React.createElement(Layout, { docId: docId, storyId: storyId },
        React.createElement(DocumentHomePage, { type: type })));
    return DocHome;
};

const useRoutes = () => {
    const routes = useMemo(() => {
        const routes = [];
        //home page
        const { path, docId, type, storyId } = getIndexPage(store) || {};
        routes.push(React.createElement(Route, { key: path, exact: true, path: path, component: DocPageTemplate({ docId, type, storyId }) }));
        const homePages = getHomePages(store);
        homePages.forEach(({ path, docId, storyId, type }) => {
            routes.push(React.createElement(Route, { key: path, exact: true, path: path, component: DocHomeTemplate({
                    type,
                    docId,
                    storyId,
                }) }));
        });
        const docPages = getDocPages(store);
        docPages.forEach(({ path, type, docId, storyId, category, activeTab }) => {
            routes.push(React.createElement(Route, { key: path, exact: true, path: path, component: DocPageTemplate({
                    type,
                    docId,
                    storyId,
                    category,
                    activeTab,
                }) }));
        });
        return routes;
    }, [store]);
    return routes;
};

export { useRoutes };
