'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var reactRouterDom = require('react-router-dom');
var controlsStore = require('@component-controls/store/controls-store');
var routes = require('@component-controls/routes');
var app = require('@component-controls/app');
var reactHelmet = require('react-helmet');
var tslib = require('tslib');
var core = require('@component-controls/core');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

const ReactRouterLink = (_a) => {
    var { href = '', children } = _a, props = tslib.__rest(_a, ["href", "children"]);
    return (React__default['default'].createElement(reactRouterDom.Link, Object.assign({ to: href }, props), children));
};

const Layout = ({ docId, storyId, children, activeTab, }) => {
    return (React__default['default'].createElement(app.AppContext, { Helmet: reactHelmet.Helmet, docId: docId, storyId: storyId, store: controlsStore.store, linkClass: ReactRouterLink, activeTab: activeTab }, children));
};

const DocPageTemplate = ({ docId, storyId, type, activeTab, category, }) => {
    const DocHome = () => (React__default['default'].createElement(Layout, { docId: docId, storyId: storyId, activeTab: activeTab },
        React__default['default'].createElement(app.DocPage, { type: type, category: category })));
    return DocHome;
};

const DocHomeTemplate = ({ type = core.defDocType, docId, storyId, }) => {
    const DocHome = () => (React__default['default'].createElement(Layout, { docId: docId, storyId: storyId },
        React__default['default'].createElement(app.DocumentHomePage, { type: type })));
    return DocHome;
};

const useRoutes = () => {
    const routes$1 = React.useMemo(() => {
        const routes$1 = [];
        //home page
        const { path, docId, type, storyId } = routes.getIndexPage(controlsStore.store) || {};
        routes$1.push(React__default['default'].createElement(reactRouterDom.Route, { key: path, exact: true, path: path, component: DocPageTemplate({ docId, type, storyId }) }));
        const homePages = routes.getHomePages(controlsStore.store);
        homePages.forEach(({ path, docId, storyId, type }) => {
            routes$1.push(React__default['default'].createElement(reactRouterDom.Route, { key: path, exact: true, path: path, component: DocHomeTemplate({
                    type,
                    docId,
                    storyId,
                }) }));
        });
        const docPages = routes.getDocPages(controlsStore.store);
        docPages.forEach(({ path, type, docId, storyId, category, activeTab }) => {
            routes$1.push(React__default['default'].createElement(reactRouterDom.Route, { key: path, exact: true, path: path, component: DocPageTemplate({
                    type,
                    docId,
                    storyId,
                    category,
                    activeTab,
                }) }));
        });
        return routes$1;
    }, [controlsStore.store]);
    return routes$1;
};

exports.useRoutes = useRoutes;
