import path from 'path';
import fs from 'fs';
import { defaultCompileProps } from '@component-controls/core';
import { getSiteMap } from '@component-controls/routes';
import { loadStore } from '@component-controls/store';
import { log } from '@component-controls/logger';
import { searchIndexing, watch, compile } from '@component-controls/webpack-compile';
import { getBundleName } from '@component-controls/core/node-utils';

const postBuild = async (staticFolder, loadingStore) => {
    if (loadingStore) {
        const store = loadStore(loadingStore, true);
        if (process.env.NODE_ENV === 'production') {
            if (store.config.siteMap) {
                const sitemap = getSiteMap(store);
                const sitemapfolder = path.resolve(staticFolder, '..');
                if (!fs.existsSync(sitemapfolder)) {
                    fs.mkdirSync(sitemapfolder, { recursive: true });
                }
                const sitemapname = path.join(sitemapfolder, 'sitemap.xml');
                log('creating sitemap', sitemapname);
                fs.writeFileSync(sitemapname, sitemap, 'utf8');
            }
            await searchIndexing(store);
        }
    }
};
const withComponentControls = ({ config, development, options, }) => async function () {
    var _a;
    const distFolder = (options === null || options === void 0 ? void 0 : options.distFolder) || path.join(process.cwd(), 'dist');
    const staticFolder = path.join((options === null || options === void 0 ? void 0 : options.distFolder) || distFolder, 'static');
    const buildOptions = Object.assign(Object.assign(Object.assign({}, defaultCompileProps), { configPath: '.config', distFolder,
        staticFolder }), options);
    const onBundle = async ({ store }) => {
        await postBuild(buildOptions.staticFolder, store);
    };
    const run = development ? watch : compile;
    await run(buildOptions, onBundle);
    return Object.assign(Object.assign({}, config), { module: Object.assign(Object.assign({}, config.module), { rules: [
                ...(((_a = config.module) === null || _a === void 0 ? void 0 : _a.rules) || []),
                {
                    test: require.resolve('@component-controls/store/controls-store'),
                    use: {
                        loader: require.resolve('@component-controls/store/loader.js'),
                        options: {
                            bundleFileName: getBundleName(buildOptions),
                        },
                    },
                },
            ] }) });
};

export { postBuild, withComponentControls };
