'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var path = require('path');
var fs = require('fs');
var core = require('@component-controls/core');
var routes = require('@component-controls/routes');
var store = require('@component-controls/store');
var logger = require('@component-controls/logger');
var webpackCompile = require('@component-controls/webpack-compile');
var nodeUtils = require('@component-controls/core/node-utils');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var path__default = /*#__PURE__*/_interopDefaultLegacy(path);
var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);

const postBuild = async (staticFolder, loadingStore) => {
    if (loadingStore) {
        const store$1 = store.loadStore(loadingStore, true);
        if (process.env.NODE_ENV === 'production') {
            if (store$1.config.siteMap) {
                const sitemap = routes.getSiteMap(store$1);
                const sitemapfolder = path__default['default'].resolve(staticFolder, '..');
                if (!fs__default['default'].existsSync(sitemapfolder)) {
                    fs__default['default'].mkdirSync(sitemapfolder, { recursive: true });
                }
                const sitemapname = path__default['default'].join(sitemapfolder, 'sitemap.xml');
                logger.log('creating sitemap', sitemapname);
                fs__default['default'].writeFileSync(sitemapname, sitemap, 'utf8');
            }
            await webpackCompile.searchIndexing(store$1);
        }
    }
};
const withComponentControls = ({ config, development, options, }) => async function () {
    var _a;
    const distFolder = (options === null || options === void 0 ? void 0 : options.distFolder) || path__default['default'].join(process.cwd(), 'dist');
    const staticFolder = path__default['default'].join((options === null || options === void 0 ? void 0 : options.distFolder) || distFolder, 'static');
    const buildOptions = Object.assign(Object.assign(Object.assign({}, core.defaultCompileProps), { configPath: '.config', distFolder,
        staticFolder }), options);
    const onBundle = async ({ store }) => {
        await postBuild(buildOptions.staticFolder, store);
    };
    const run = development ? webpackCompile.watch : webpackCompile.compile;
    await run(buildOptions, onBundle);
    return Object.assign(Object.assign({}, config), { module: Object.assign(Object.assign({}, config.module), { rules: [
                ...(((_a = config.module) === null || _a === void 0 ? void 0 : _a.rules) || []),
                {
                    test: require.resolve('@component-controls/store/controls-store'),
                    use: {
                        loader: require.resolve('@component-controls/store/loader.js'),
                        options: {
                            bundleFileName: nodeUtils.getBundleName(buildOptions),
                        },
                    },
                },
            ] }) });
};

exports.postBuild = postBuild;
exports.withComponentControls = withComponentControls;
